`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////
// Company: 
// Engineer: 
// 
// Create Date:    14:34:54 04/14/2016 
// Design Name: 
// Module Name:    lab07_1_24-hour 
// Project Name: 
// Target Devices: 
// Tool versions: 
// Description: 
//
// Dependencies: 
//
// Revision: 
// Revision 0.01 - File Created
// Additional Comments: 
//
//////////////////////////////////////////////////////////////////////////////////
module lab07_1_24hour(
  display, // 14 segment display control
  ftsd_ctl, // scan control for 14-segment display
  clk, // clock
  rst_n, // low active reset
  modesel // input control for FSM
	);
	output [14:0] display; // 14 segment display control
	output [3:0] ftsd_ctl; // scan control for 14-segment display
	input clk; // clock
	input rst_n; // low active reset
	input modesel; // input control for FSM

	wire [1:0] ftsd_ctl_en; // divided output for ssd scan control
	wire clk_d,clk_debounce; // divided clock

	wire count_enable; // if count is enabled

	wire modesel_debounce;
	wire modesel_dealed;

	wire [3:0] dis0,dis1,dis2,dis3;

	wire [3:0] dig0,dig1; // second counter output
	wire [3:0] ftsd_in; // input to 14-segment display decoder

	
	// frequency divider 1/(2^25)
	freq_div U_1(
	  .clk_out(clk_d), // divided clock
	  .clk_ctl(ftsd_ctl_en), // divided clock for scan control 
	  .clk(clk), // clock from the crystal
	  .rst_n(rst_n), // low active reset
	  .clk_debounce(clk_debounce)
	);

	// 60 up counter
	hourscounter U_2(
	  .hour1(dig1), // digit 1 for second
	  .hour0(dig0), // digit 0 for second
	  .clk(clk_d), // global clock
	  .rst_n(rst_n) //active low reset
	);
	
	//FSM 
	mode U_3(
	  .hour1(dig1),
	  .hour0(dig0),
	  .clk(clk_debounce),
	  .rst_n(rst_n),
	  .modesel(modesel_dealed),
	  .showout0(dis0),
	  .showout1(dis1),
	  .showout2(dis2),
	  .showout3(dis3)
	);
	
	// Scan control
	scan_ctl U_4(
	  .ftsd_ctl(ftsd_ctl), // ftsd display control signal 
	  .ftsd_in(ftsd_in), // output to ftsd display
	  .in0(dis3), // 1st input
	  .in1(dis2), // 2nd input
	  .in2(dis1), // 3rd input
	  .in3(dis0),  // 4th input
	  .ftsd_ctl_en(ftsd_ctl_en) // divided clock for scan control
	);

	// binary to 14-segment display decoder
	ftsd U_5(
	  .display(display), // 14-segment display output
	  .bcd(ftsd_in)  // BCD number input
	);

	
	//Deal with mode select signal
	//Include CG,DC,OP
	
	debounce_circuit U_6(
	  .clk(clk_debounce), // clock control
	  .rst_n(rst_n), // reset
	  .pb_in(modesel), //push button input
	  .pb_debounced(modesel_debounce) // debounced push button output
	);
	one_pulse U_7(
	  .clk(clk_debounce),  // clock input
	  .rst_n(rst_n), //active low reset
	  .in_trig(modesel_debounce), // input trigger
	  .out_pulse(modesel_dealed) // output one pulse 
	);


endmodule
